﻿package {
	import sk.prasa.webapis.picasa.PicasaResponder;
	import sk.prasa.webapis.picasa.PicasaService;
	import sk.prasa.webapis.picasa.events.PicasaDataEvent;
	import flash.system.Security;
	import flash.display.*;
	import flash.events.*;
	import flash.net.*;

	public class Main extends Sprite {
		//ユーザIDとアルバムIDを指定
		private var userID:String='tadokoro';
		private var alubumID:String='5560743918853662497';
		private var selectNum:int;
		//Pivasa APIサービス
		private var service:PicasaService;

		//写真データ
		private var picasaData:PicasaDataEvent;

		public function Main() {
			//クロスドメインポリシーファイルの読み込み
			Security.loadPolicyFile("http://photos.googleapis.com/data/crossdomain.xml");
			init();

			//ステージ設定(ブラウザ全画面表示)
			stage.scaleMode=StageScaleMode.NO_SCALE;
			stage.align=StageAlign.TOP_LEFT;
		}
		
		private function init():void {
			//Picasa APIのサービスを新規に生成
			service = new PicasaService();
			//使用可能な画像サイズ一覧 (Pixel)
			//32, 48, 64, 72, 144, 160, 200, 288, 320, 400, 512, 576, 
			//640, 720, 800, 912, 1024, 1152, 1280, 1440, 1600

			//最大の幅
			service.imgmax="800";
			//サムネイルのサイズ
			service.thumbsize="64";
			//最大読込枚数
			service.max_results=100;
			//ユーザIDとアルバムIDを指定して、情報を読み込み
			var responder:PicasaResponder=service.photos.list(userID,alubumID);
			//情報の読込みが完了した際に発生するイベントリスナーの登録
			responder.addEventListener(PicasaDataEvent.DATA, onCompleteHandler);
		}

		private function onCompleteHandler(_picasaData:PicasaDataEvent):void {
			picasaData=_picasaData;
			var slideRowCount:int = stage.stageWidth / (int(service.thumbsize) + 12);
			for (var i:int = 0; i < picasaData.data.entries.length; i++) {
				//サムネイルとコンテントのURLを引数に
				showThumbail(i, (i%slideRowCount)*76 + 4, int(i/slideRowCount)*90 + 4);
			}
		}

		private function showThumbail(num:int, posX:int, posY:int):void {
			//サムネール読込のベースとなるムービーを配置
			var thumbnailMc:Thumbnail = new Thumbnail();
			addChild(thumbnailMc);
			//ムービに情報を付加
			thumbnailMc.x=posX;
			thumbnailMc.y=posY;
			thumbnailMc.num=num;
			thumbnailMc.buttonMode=true;
			thumbnailMc.media=picasaData.data.entries[num].media;
			trace(thumbnailMc.media);
			thumbnailMc.title=picasaData.data.entries[num].media.title;
			thumbnailMc.description=picasaData.data.entries[num].media.description;
			thumbnailMc.credit=picasaData.data.entries[num].media.credit;
			//サムネイルにタイトル表示
			thumbnailMc.titleText.text=thumbnailMc.title;

			//Loaderを配置
			var imageLoader:Loader = new Loader();
			var imageURLreq:URLRequest=new URLRequest(picasaData.data.entries[num].media.thumbnails[0].url);
			var imgInfo:LoaderInfo=imageLoader.contentLoaderInfo;
			thumbnailMc.loader.addChild(imageLoader);
			imageLoader.load(imageURLreq);
			//クリックで拡大画像表示;
			imageLoader.addEventListener(MouseEvent.CLICK, clickThumbnailHandler);
		}

		private function clickThumbnailHandler(event:MouseEvent):void {
			var thumbnailMc:Thumbnail=event.target.parent.parent;
			//ズーム表示のベースとなるムービーを配置
			var photoZoomMc:PhotoZoom = new PhotoZoom();
			addChild(photoZoomMc);
			photoZoomMc.backScreen.width=stage.stageWidth;
			photoZoomMc.backScreen.height=stage.stageHeight;
			photoZoomMc.x=int(stage.stageWidth/2);
			photoZoomMc.y=int(stage.stageHeight/2);
			photoZoomMc.buttonMode=true;

			//拡大した写真をロードする
			var num:int=int(thumbnailMc.num);
			var contentUrl:String=picasaData.data.entries[num].media.content.url;
			var imageLoader:Loader = new Loader();
			var imageURLreq:URLRequest=new URLRequest(contentUrl);
			var imgInfo:LoaderInfo=imageLoader.contentLoaderInfo;
			photoZoomMc.addChild(imageLoader);

			//拡大画像のローダー配置
			imageLoader.load(imageURLreq);
			imageLoader.x=- thumbnailMc.media.content.width/2;
			imageLoader.y=- thumbnailMc.media.content.height/2;

			//場所と大きさを写真にあわせて補正
			photoZoomMc.photobase.width=thumbnailMc.media.content.width+20;
			photoZoomMc.photobase.height=thumbnailMc.media.content.height+60;
			photoZoomMc.photobase.y=20;

			//写真のタイトルと説明を表示
			photoZoomMc.titleText.text=thumbnailMc.title;
			photoZoomMc.descriptionText.text=thumbnailMc.description;

			//クリックで消去
			photoZoomMc.addEventListener(MouseEvent.CLICK, clickZoomHandler);
		}

		private function clickZoomHandler(event:MouseEvent):void {
			removeChild(event.target.parent);
		}
	}
}